<?php
/*
Plugin Name: BCT for Gravity Forms
Description: Button Click Text is a really simple way for people using your form to see that your form is actually working when they push the submit button. The "click text" will change from the original submit text to anything you desire.
Version: 1.0
Author: ZeroZen Design
Tested up to: 5.3.2
Author URI: https://www.zerozendesign.com

*/

define( 'GF_BCT_VERSION', '1.0' );
define('GF_BCT_DIR', plugin_dir_path(__FILE__) );
define('GF_BCT_URL', plugin_dir_url(__FILE__));


add_action( 'gform_loaded', array( 'GF_BCT_ADDON', 'load' ), 35 );

class GF_BCT_ADDON {

	public static function load() {

		if ( ! method_exists( 'GFForms', 'include_feed_addon_framework' ) ) {
			return;
		}
		
		if ( ! file_exists( GF_BCT_DIR.'class-button-text-addon.php' ) ) {
			define( 'BCT_PLUGIN_TYPE', 0 );			
		}
		else {			
			require_once( 'class-button-text-addon.php' );
			GFAddOn::register( 'GFButtonTextAddOn' );
		}
		
		wp_enqueue_script( "bct-submit", plugin_dir_url( __FILE__ )."js/button.js", array('jquery'), rand(1,122), true );
		
	}
}

add_filter( 'gform_form_settings', 'bct_settings_field', 10, 2 );
function bct_settings_field( $settings, $form )  {
	
	global $__gf_tooltips;
	$__gf_tooltips['bct_switcher_tooltip'] = "Entered text here will replace the submit button text when clicked.";
	
	$settings['BCT Settings'] = array();
	
	$settings['BCT Settings'][] = '
	<tr>
		<th>
			<label for="bct_default_click_text">Default Switch Text</label> '.gform_tooltip( 'bct_switcher_tooltip', '', true ).'
		</th>
		<td>

			<input type="text" id="bct_default_click_text" class="fieldwidth-1" name="bct_default_click_text" value="'.rgar($form, 'bct_default_click_text').'" />

		</td>
	</tr>';
	
	$new_settings = array();
	
	foreach($settings as $key => $val) {
		
		$new_settings[$key] = $val;
		if( $key == "Form Button" ) {
			$new_settings['BCT Settings'] = $settings['BCT Settings'];
		}	
	}
	
	return $new_settings;
}

add_filter( 'gform_pre_form_settings_save', 'bct_save_form_setting' );
function bct_save_form_setting($form) {
    $form['bct_default_click_text'] = rgpost( 'bct_default_click_text' );
	return $form;
}

add_filter("gform_pre_render", "bct_pre_render_setup", 100, 1);
function bct_pre_render_setup($form) {
	$form_id = $form['id'];
	$button = $form['button'];
	
	$button_click_text = ! empty( $form['bct_default_click_text'] ) ? $form['bct_default_click_text'] :  false ;
	$button_default_text = ! empty( $button['text'] ) ? $button['text'] : __( 'Submitx', 'gravityforms' );
		
	$custom_button_text['default'] = $button_default_text;
	$custom_button_text['default_click_text'] = $button_click_text;
	
	$custom_button_data['text'] = $custom_button_text;
	$custom_button_data['form_id'] = $form_id;
	
	if( $button_click_text ) {
		echo "<script type='text/javascript'> 
				if( typeof custom_button_data == 'undefined' || ! Array.isArray(custom_button_data) ) {
					custom_button_data = new Array();
				}
				custom_button_data['$form_id'] = ".json_encode($custom_button_data)."
			</script>";
	}
	return $form;
}














